# soak
Process aridity templates en masse, like Helm but much more DRY.

This README is auto-generated, see [project wiki](https://wikiwheel.net/s/foyono/w/soak) for details.

## Commands

### soak
Process aridity templates as per all soak.arid configs in directory tree.

## API

<a id="soak.context"></a>

### soak.context

<a id="soak.util"></a>

### soak.util

